@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: getprefix.py - Last Update: 3/9/2023 Ver. 2.7.26 RC 1 - Author: cooldude2k $
+    $FileInfo: getprefix.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -409,7 +409,9 @@ def get_goodwill_upca_barcode_info(upc, infotype=None):
   gw_item_color = None;
  price_matches = re.findall("^(\d{3})(\d{2})", upc_matches[1]);
  price_matches = price_matches[0];
- if(price_matches[0]=="699" and gw_item_type=="Mystery Dozen Deal"):
+ if(price_matches[0]=="399" and gw_item_type=="Mystery Dozen Deal"):
+  gw_item_type = "Mystery DVD Deal";
+ elif(price_matches[0]=="699" and gw_item_type=="Mystery Dozen Deal"):
   gw_item_type = "Mystery 1/2 Dozen Deal";
  elif(price_matches[0]=="999" and gw_item_type=="Mystery Dozen Deal"):
   gw_item_type = "Mystery Dozen Deal";
